/* File: scanner.h
 * ---------------
 * Ovu datoteku ne treba mijenjati . Ovdje se deklarisu konstante,
 * tipovi, promejnljive i funkcije koje se koriste u skeneru i/ili se 
 * eksportuju.
 */

#ifndef _H_scanner
#define _H_scanner

#include <stdio.h>

#define MaxIdentLen 31    // Maximum length for identifiers

  
/* Typedef: TokenType enum
 * -----------------------
 * Ova enumeracija definise konstante za razlicite tipove tokena.
 * Skener treba da vrati neku od ovih vrijednosti i tip tokena.  
 */
typedef enum { 
    T_Void = 256,
    T_Int, T_Double, T_Bool, T_String, T_Class, T_Null, 
    T_LessEqual, T_GreaterEqual, T_Equal, T_NotEqual, T_And, T_Or,
    T_While, T_For, T_If, T_Else, T_Return, T_Break,
    T_Extends, T_This, T_Implements, T_Interface, T_New, T_NewArray,
    T_Identifier, T_StringConstant, T_IntConstant, T_DoubleConstant,
    T_BoolConstant,
    T_NumTokenTypes
} TokenType;

 
/* Ovo je lista imena ya stampanje za svaki token dat u prethodnoj enumeraciji. 
 * Stringovi odgovaraju pozicij u tipu. Koriste se u main-u za 
 * verifikaciju skenera.
 */
static const char *gTokenNames[T_NumTokenTypes] = {
  "T_Void", "T_Int", "T_Double", "T_Bool", "T_String", "T_Class", "T_Null",
  "T_LessEqual", "T_GreaterEqual", "T_Equal", "T_NotEqual",
  "T_And", "T_Or", "T_While", "T_For", "T_If", "T_Else", "T_Return",
  "T_Break", "T_Extends", "T_This", "T_Implements", "T_Interface",
  "T_New", "T_NewArray","T_Identifier", "T_StringConstant",
  "T_IntConstant", "T_DoubleConstant", "T_BoolConstant", 
};

 
/* Typedef: YYSTYPE
 * ----------------
 * Definise union tip koji sluzi za cuvanje atributa tokena koji se skenira. 
 */
typedef union {
    int integerConstant;
    bool boolConstant;
    char *stringConstant;
    double doubleConstant;
    char identifier[MaxIdentLen+1]; // +1 for terminating null
} YYSTYPE;

 
/* Global variable: yylval
 * -----------------------
 * Po konvenciji, ovo je ime unije koju upisju skener a cita je parser. 
 * Sadrzi informaciju o upravo skenirajoj leksimi. 
 */
extern YYSTYPE yylval;

extern char *yytext;      // Tekst skenrane leksim


int yylex();              // Definisano u generisanom lex.yy.c file
void yyrestart(FILE *fp); // Isto kao prethodno


void InitScanner();                 // Definisano u scanner.l / korisnicka procedura
 
#endif
