/* File:  scanner.l
 * ----------------
 * Ulazni lex fajl za generisanje skenera.
 */

%{

/* Tekst unutar ovih simbola %{ i %} treba da bude C/C++ kod i direktno se 
 * kopira lex.yy.c fajl ispred definicije yylex() funkcije. Dodati druge 
 * header fajlove ili definicije.prototipove koje us Vam potrebne. 
 */

#include <string.h>
#include "scanner.h"
#include "errors.h"  /*Ovo vi treba da definisete*/

/* Global variable: yylval
 * -----------------------
 * Ova globalna promjenljiva je nacin kako dobijamo informaciu o atributima 
 * upravo skeniranog tokena. Skener postavlja globalnu promjenljivu a klijent 
 * je samo cita.
 */
YYSTYPE yylval;  // rucno definisana, kasnije je daje Bison

/* Global variable: yylloc
 * -----------------------
 * Promjenljiva koja cuva informaciju o poziciji unutar tokena
 * jkoji je upravo skeniran. (Ponasa se slicno kao yylval.)
 */
struct yyltype yylloc; // rucno definisana, kasnije je daje Bison

/* Macro: YY_USER_ACTION 
 * ---------------------
 * Ovaj flex built-in macro moze se definisati da uradi akciju koja treba
 * da se uvijek izvrsi prije bilo kojeg poklapanja. To je nacin da imate dio 
 * koda koji je zajednicki za sve akcije izdvojen u posebnoj rutini. 
 * Ovdje je data definicija a vi treba da napisete kod. Pozivace se svaki put
 * kada se skenira sablon u fajlu, prije izvrsavanja akcije.
 */
static void DoBeforeEachAction(); 
#define YY_USER_ACTION DoBeforeEachAction();

%}

 /* Sekcija prije prvog %% je za defincije lex ulaynog fajla.
  * Ovdje se postavljaju opcije vaseg skenera, definisu lex stanja, 
  * i mogu se zadati imena regularnim izrazima. 
  */


%%             /* POCETAK SEKCIJE SA PRAVILIMA */
 /* Svi sabloni i akcije moraju biti iynedju pocetnog i zavrsnog 
  * simbola %%.  
  */ 

%%
/* Simbol %% iznad oznacava kraj skecije pravila i pocetak sekcije 
 * korisnickih procedura. Sav tekst iz ove sekcije direktno se kopira 
 * generisani lex.yy.c file. Uovoj sekciji dodajte vase pomocne funkcije. 
 */


/* Function: InitScanner
 * ---------------------
 * Ova funkcija treba da se pozove prije poziva  yylex(). Mnamijenjena je da  
 * u njoj odradite sve sto je potrebno za inicijalizaciju skenera 
 * (postavljanje globalnih promjenljivih, konfiguracija pocetnog stanja, itd.). 
 * Samo je postavljena jedna opcija - yy_flex_debug je postavljena na false. 
 */
void InitScanner()
{
 /*   PrintDebug("lex", "Initializing scanner");*/
    yy_flex_debug = false;
}


/* Function: DoBeforeEachAction()
 * ------------------------------
 * Ova je funckija instalirana kao YY_USER_ACTION. Ovdje treba grupisati 
 * kod koji je zajednicki za sve akcije. 
 */
static void DoBeforeEachAction()
{
}
